.. _all-salt.serializers:

==================
serializer modules
==================

.. currentmodule:: salt.serializers

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    configparser
    json
    msgpack
    python
    yaml
    yamlex
